kill me

```python
from bunk_py import BunkResult, BunkAPI

bunk = BunkAPI(token='Token Here',id=Discord ID HERE)
y = bunk.donkey()
print(f"{y.title}: {y.image}")
```

Attributes for `donkey, meme, llama, alpaca, giraffe, potato, moose, aww, camel, seal, zebra, elephant, amongus`:
```
method - The method used.
image - The URL of the Image.
upvote - The number of upvotes.
downvote - The number of downvotes.
comments - The number of comments.
created_at - The time it was made.
nsfw - if the picture is NSFW.
score - its score.
subreddit - The subreddit it came from.
title - the title dumbass
id - id bitch
author - author bitch
```

Attributes for `space`:
```
image - the url of the image.
```

Attributes for `8ball`:
```
None, it literally returns a string response
```

Attribuets for `anime_wallpaper`:
```
title - title bitch
image - image bitch
```
